/// <reference path="../hoops_web_viewer.d.ts"/>
/// <reference path="../common/Example.ts"/>
/// <reference path="../common/ModelTree.ts"/>
var Example;
(function (Example) {
    var ComparisonExample = /** @class */ (function () {
        function ComparisonExample() {
            this._selectedNodeId = null;
			this._fiestNode = null;
			this._secondeNode = null;
        }
        ComparisonExample.prototype.start = function (viewerOptions) {
            var _this = this;
            return Example.createViewer(viewerOptions).then(function (viewer) {
                _this._viewer = viewer;
                _this._modelTree = new Example.Ui.ModelTree("modelTree", _this._viewer);
                _this._bindEvents();
                _this._viewer.start();
            });
        };
        ComparisonExample.prototype._bindEvents = function () {
            var _this = this;
            this._viewer.setCallbacks({
                firstModelLoaded: function () {
                    _this._modelTree.viewNode(_this._viewer.model.getAbsoluteRootNode());
                },
                selectionArray: function (selections) {
                    for (var _i = 0, selections_1 = selections; _i < selections_1.length; _i++) {
                        var selection = selections_1[_i];
                        _this._onSelection(selection);
                    }
                },
            });
            var element = document.getElementById("loadModels");
            element.onclick = function () {
                var model = _this._viewer.model;
                var nodeId = model.getAbsoluteRootNode();
				
				_this._fiestNode = model.createNode(nodeId, "node");
				_this._secondeNode = model.createNode(nodeId, "node");
                
                // Load model
				model.loadSubtreeFromModel(_this._fiestNode, "bnc1").then(function () {
                   ;
                });
				 model.loadSubtreeFromModel(_this._secondeNode, "bnc2").then(function () {
                    _this._modelTree.viewNode(nodeId);
                });
				
				
            };
          
            element = document.getElementById("startComp");
            element.onclick = function () {
				if( _this._fiestNode && _this._secondeNode)
				{
	
				   var Nodes1 = [_this._fiestNode];
				   var Nodes2 = [_this._secondeNode];
				  _this._viewer.view.startComparison(Nodes1,Nodes2);
				}
            };
			element = document.getElementById("endComp");
            element.onclick = function () {
               _this._viewer.view.endComparison();
            };
        };
        ComparisonExample.prototype._onSelection = function (selectionEvent) {
            var selection = selectionEvent.getSelection();
            if (selection.isNodeSelection()) {
                var model = this._viewer.model;
                var nodeId = selection.getNodeId();
                if (model.isNodeLoaded(nodeId)) {
                    this._selectedNodeId = nodeId;
                    // If we selected a body, then get the assembly node that holds it (loadSubtreeFromXXX() works on assembly nodes)
                    if (model.getNodeType(this._selectedNodeId) ===
                        Communicator.NodeType.BodyInstance) {
                        var parent_1 = model.getNodeParent(this._selectedNodeId);
                        if (parent_1 !== null) {
                            this._selectedNodeId = parent_1;
                        }
                    }
                }
            }
        };
       
        return ComparisonExample;
    }());
    Example.ComparisonExample = ComparisonExample;
})(Example || (Example = {}));
